@@ -29,8 +29,16 @@ def dispatch(event, context):
         proto = _get_proto(dispatch.action, dispatch.payload.value)
         return handler(proto, context)
     except Exception as e:
-        print("Unexpected exception:", str(e))
-        return {"OK": False, "error": str(e)}
+        print("Handler failed:", str(e))
+        return error_response(str(e))
+
+
+def ok_response():
+    return {"OK": True}
+
+
+def error_response(message):
+    return {"OK": False, "error": message}
 
 
 def _get_handler(action):
